<?php
/**
 * Latin language file
 *
 * @author Massimiliano Vassalli <vassalli.max@gmail.com>
 */
$lang['menu']                  = 'Optiones Administrationis';
$lang['error']                 = 'Optiones non nouatae ob errores: rursum temptat. Errores rubro colore signati sunt.';
$lang['updated']               = 'Optiones feliciter nouatae.';
$lang['nochoice']              = '(nulla optio est)';
$lang['locked']                = 'Optio documenti non nouata est, <br/> optiones et facultates documenti inspicis.';
$lang['danger']                = 'CAVE: si has optiones mutabis, in administrationis indicem non inire potes.';
$lang['warning']               = 'CAVE: si hae optiones mutabis, graues errores erunt.';
$lang['security']              = 'CAVE: si hae optiones mutabis, graues errores erunt.';
$lang['_configuration_manager'] = 'Optionum administratio';
$lang['_header_dokuwiki']      = 'Vicis Optiones';
$lang['_header_plugin']        = 'Addendorum Optiones';
$lang['_header_template']      = 'Vicis Formae Optiones';
$lang['_header_undefined']     = 'Variae Optiones';
$lang['_basic']                = 'Praecipuae Optiones';
$lang['_display']              = 'Speciei Optiones';
$lang['_authentication']       = 'Confirmationis Optiones';
$lang['_anti_spam']            = 'In Mala Optiones';
$lang['_editing']              = 'Recensendi Optiones';
$lang['_links']                = 'Nexi Optiones';
$lang['_media']                = 'Visiuorum Optiones';
$lang['_advanced']             = 'Maiores Optiones';
$lang['_network']              = 'Interretis Optiones';
$lang['_msg_setting_undefined'] = 'Res codicum sine optionibus.';
$lang['_msg_setting_no_class'] = 'Classes sine optionibus';
$lang['_msg_setting_no_default'] = 'Nihil';
$lang['fmode']                 = 'Documentum creandum ratio';
$lang['dmode']                 = 'Scrinia creandam ratio';
$lang['lang']                  = 'Linguae optiones';
$lang['basedir']               = 'Computatoris seruitoris domicilium (ex. <code>/dokuwiki/</code>). Nihil scribere si id machinatione agnoscere uis.';
$lang['baseurl']               = 'Computatoris seruitoris VRL (ex. <code>http://www.yourserver.com</code>). Nihil scribere si id machinatione agnoscere uis.';
$lang['savedir']               = 'Documentorum seruatorum domicilium';
$lang['start']                 = 'Nomen paginae dominicae';
$lang['title']                 = 'Vicis titulus';
$lang['template']              = 'Vicis forma';
$lang['license']               = 'Sub quibus legibus uicem creare uin?';
$lang['fullpath']              = 'Totum domicilium paginae in pedibus scribis.';
$lang['recent']                = 'Extremae mutationes';
$lang['breadcrumbs']           = 'Numerus uestigiorum';
$lang['youarehere']            = 'Ordo uestigiorum';
$lang['typography']            = 'Signa supponentes';
$lang['dformat']               = 'Forma diei (uide paginam <a href="http://php.net/strftime">de diebus</a>)';
$lang['signature']             = 'Subscriptio';
$lang['toptoclevel']           = 'Gradus maior tabularum argumentorum';
$lang['tocminheads']           = 'Minimus numerus capitum';
$lang['maxtoclevel']           = 'Maximus numerus tabularum argumentorum';
$lang['maxseclevel']           = 'Maxima pars gradus recensendi';
$lang['camelcase']             = 'SignaContinua nexis apta facere';
$lang['deaccent']              = 'Titulus paginarum abrogare';
$lang['useheading']            = 'Capite primo ut titulo paginae uti';
$lang['refcheck']              = 'Documenta uisiua inspicere';
$lang['allowdebug']            = '<b>ineptum facias si non necessarium!</b> aptum facere';
$lang['usewordblock']          = 'Malum interretiale ob uerba delere';
$lang['indexdelay']            = 'Tempus transitum in ordinando (sec)';
$lang['relnofollow']           = 'rel="nofollow" externis nexis uti';
$lang['mailguard']             = 'Cursus interretiales abscondere';
$lang['iexssprotect']          = 'Documenta nouata ob mala JavaScript uel HTML inspicere';
$lang['showuseras']            = 'Quid, cum Sodalem, qui extremus paginam recensuit, ostendat, scribere';
$lang['useacl']                = 'Aditus inspectionis indicibus uti';
$lang['autopasswd']            = 'Tessera machinatione generata';
$lang['authtype']              = 'Confirmationis finis';
$lang['passcrypt']             = 'Ratio tesserae tuendae';
$lang['defaultgroup']          = 'Grex communis';
$lang['superuser']             = 'Magister\stra - grex, Sodalis uel index diuisus a uigulis sodalis1,@grex,sodalis2 cum plenis facultatibus sine ICA optionum termino';
$lang['manager']               = 'Administrator - grex, Sodalis uel index diuisus a uigulis sodalis1,@grex,sodalis2 cum certis facultatibus';
$lang['profileconfirm']        = 'Mutationes tessera confirmanda sunt';
$lang['disableactions']        = 'Vicis actiones ineptas facere';
$lang['disableactions_check']  = 'Inspicere';
$lang['disableactions_subscription'] = 'Inscribe/Delere';
$lang['disableactions_wikicode'] = 'Fontem uidere/Rudem transcribere';
$lang['disableactions_other']  = 'Aliae actiones (uirgulis diuisae)';
$lang['sneaky_index']          = 'Hic uicis omnia genera in indice inserit. Si ineptam hanc optionem facias, solum ea, quae Sodales uidere possunt, in indice erunt. Hoc suggreges et suggenera abscondere potest.';
$lang['auth_security_timeout'] = 'Confirmationis Tempus (secundis)';
$lang['securecookie']          = 'Formulae HTTPS mittine solum per HTTPS possunt? Ineptam hanc optio facias, si accessus uicis tutus est, sed interretis non.';
$lang['updatecheck']           = 'Nouationes et fiducias inspicerene? Hic uicis connectere update.dokuwiki.org debes.';
$lang['userewrite']            = 'VRL formosis uti';
$lang['useslash']              = 'Repagula in URL, ut genera diuidas, uti';
$lang['usedraft']              = 'Propositum in recensione machinatione seruatur';
$lang['sepchar']               = 'Signum, quod paginas diuidit';
$lang['canonical']             = 'VRL perfecto uti';
$lang['fnencode']              = 'Ratio quae nomen documentorum non-ASCII codificit';
$lang['autoplural']            = 'Pluralia in nexis inspicere';
$lang['compression']           = 'Ratio compressionis documentis "attic"';
$lang['cachetime']             = 'Maximum tempus formulis (sec)';
$lang['locktime']              = 'Maximum tempus documentis inclusis (sec)';
$lang['fetchsize']             = 'Maximum pondus (bytes), quod fetch.php ab externis onerare potest';
$lang['notify']                = 'Adnotationis mutationes ad hunc cursum mittere';
$lang['registernotify']        = 'De nouis Sodalibus ad hunc cursum notas mittere';
$lang['mailfrom']              = 'Cursus interretialis, quo in cursibus uti';
$lang['gzip_output']           = 'gzip Argumentum-Codificans xhtml uti';
$lang['gdlib']                 = 'GD Lib forma';
$lang['im_convert']            = 'Domicilium machinae ImageMagick\'s';
$lang['jpg_quality']           = 'JPG compressio colorum (0-100)';
$lang['subscribers']           = 'Inscriptionis paginarum auxilium aptus facere';
$lang['subscribe_time']        = 'Tempus post quod inscriptionum index et summa missa sunt (sec); Hic minor quam tempus declaratum fortasse est.';
$lang['compress']              = 'CSS et javascript dimissio';
$lang['hidepages']             = 'Paginas congruentes abscondere (uerba regularia)';
$lang['send404']               = 'Mitte "HTTP 404/ Pagina non reperta" si paginae non sunt.';
$lang['sitemap']               = 'Google formam situs gignere (dies)';
$lang['broken_iua']            = 'ignore_user_abort functio inepta estne? Hoc indicem quaestionum, quae non aptae sunt, creare non potest. IIS+PHP/CGI ineptum est. Vide <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>';
$lang['xsendfile']             = 'X-Sendfile utine ut seruitor interretialis documenta firma creet? Tuus seruitor interretialis hunc pati debes.';
$lang['renderer_xhtml']        = 'Quid dimittere ut hoc in principio uicis (xhtml) utaris';
$lang['renderer__core']        = '%s (uicis nucleus)';
$lang['renderer__plugin']      = '%s (addenda)';
$lang['rememberme']            = 'Formulas aditus aptas facere (memento me)';
$lang['rss_type']              = 'XML summae genus';
$lang['rss_linkto']            = 'XML summae connectio';
$lang['rss_content']           = 'Quid in XML summis uidere?';
$lang['rss_update']            = 'XML summae renouationis interuallum temporis';
$lang['recent_days']           = 'Numerus mutationum recentium tenendorum (dies)';
$lang['rss_show_summary']      = 'XML summa titulos ostendit';
$lang['target____wiki']        = 'Fenestra nexis internis';
$lang['target____interwiki']   = 'Fenestra nexis inter uicem';
$lang['target____extern']      = 'Fenestra nexis externis';
$lang['target____media']       = 'Fenestra nexis uisiuis';
$lang['target____windows']     = 'Fenestra nexis fenestrarum';
$lang['proxy____host']         = 'Proxis seruitoris nomen';
$lang['proxy____port']         = 'Proxis portus';
$lang['proxy____user']         = 'Proxis nomen sodalis';
$lang['proxy____pass']         = 'Proxis tessera';
$lang['proxy____ssl']          = 'SSL ut connectas uti';
$lang['proxy____except']       = 'Verba, ut VRL inspicias, quibus Proxis non agnoscitur.';
$lang['license_o_']            = 'Nihil electum';
$lang['typography_o_0']        = 'neuter';
$lang['typography_o_1']        = 'sine singulis uirgulis';
$lang['typography_o_2']        = 'cum singulis uirgulis';
$lang['userewrite_o_0']        = 'neuter';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWiki domesticus';
$lang['deaccent_o_0']          = 'ex';
$lang['deaccent_o_1']          = 'accentum tollere';
$lang['deaccent_o_2']          = 'Latinis litteris';
$lang['gdlib_o_0']             = 'GD Lib inepta';
$lang['gdlib_o_1']             = 'Forma 1.x';
$lang['gdlib_o_2']             = 'Machinatione inspicere';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Summa';
$lang['rss_content_o_diff']    = 'Comparatio una';
$lang['rss_content_o_htmldiff'] = 'Tabulae HTML formatae comparatae';
$lang['rss_content_o_html']    = 'Pagina cum HTML';
$lang['rss_linkto_o_diff']     = 'discrimina uidere';
$lang['rss_linkto_o_page']     = 'pagina recensita';
$lang['rss_linkto_o_rev']      = 'recensionum index';
$lang['rss_linkto_o_current']  = 'hic pagina';
$lang['compression_o_0']       = 'neuter';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'Noli uti';
$lang['xsendfile_o_2']         = 'Praecipuus X-Sendfile';
$lang['xsendfile_o_3']         = 'Proprietarius Nginx X-Accel-Redirect';
$lang['showuseras_o_loginname'] = 'Sodalis nomen';
$lang['showuseras_o_username'] = 'Sodalis nomen uerum';
$lang['showuseras_o_email']    = 'Sodalis cursus interretialis (absconditus ut is tueratur)';
$lang['showuseras_o_email_link'] = 'Sodalis cursus interretialis ut mailto: nexum';
$lang['useheading_o_0']        = 'Numquam';
$lang['useheading_o_navigation'] = 'Solum adspicere';
$lang['useheading_o_content']  = 'Solum uicis argumentum';
$lang['useheading_o_1']        = 'Semper';
$lang['readdircache']          = 'Maximum tempus readdir (sec)';
